==> MeatAxe-2.4.8.tar.gz: mtx/2.4/src/vec2mat.c <==
/* ============================= C MeatAxe ==================================
   File:        $Id: vec2mat.c,v 1.1.1.1 2000/01/07 16:42:27 mringe Exp $
   Comment:     Convert vector to matrix.
   --------------------------------------------------------------------------
   (C) Copyright 1999 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   This program is free software; see the file COPYING for details.
   ========================================================================== */


#include "meataxe.h"


/* --------------------------------------------------------------------------
   Local data
   -------------------------------------------------------------------------- */

MTX_DEFINE_FILE_INFO 



/*{{{ --------------------------------------------------------------------------
!section algo.tp
!function VectorToMatrix "Convert vector to matrix"
!arg vecs
    List of vectors.
!arg n
    Number of the vector to convert.
!arg noc
    Desired number of columns.
!return
    $0$ on success, $-1$ on error.
!description
    This function converts a vector with $m=rc$ entries into a $r\times c$ 
    matrix by filling the matrix from top to bottom and left to right with
    the entries of the vector. The vector is taken as the $n$-th row of
    |vecs|. A new matrix is allocated and returned. |noc| is the number of
    columns of the result, which must be a divisor of the number of columns 
    of |vecs|.
!seealso MatrixToVector
-------------------------------------------------------------------------- }}}*/

Matrix_t *VectorToMatrix(Matrix_t *vecs, int n, int noc)

{
    int i;
    Matrix_t *result;

    /* Check arguments.
       ---------------- */
    if (!MatIsValid(vecs))
    {
	MTX_ERROR1("vecs: %E",MTX_ERR_BADARG);
	return NULL;
    }
    if (noc > vecs->Noc || vecs->Noc % noc != 0)
    {
	MTX_ERROR3("noc=%d (vec:%d): %E",noc,vecs->Noc,MTX_ERR_BADARG);
	return NULL;
    }

    /* Convert the vector.
       ------------------- */
    result = MatAlloc(vecs->Field,vecs->Noc / noc,noc);
    if (result == NULL)
	return NULL;
    for (i = 0; i < result->Nor; ++i)
    {
	if (MatCopyRegion(result,i,0, vecs,n,i*noc,1,noc) != 0)
	    MTX_ERROR("Copy failed");
    }
    return result;
}

==> MeatAxe-2.4.9.tar.gz: mtx/2.4/src/vec2mat.c <==
/* ============================= C MeatAxe ==================================
   File:        $Id: vec2mat.c,v 1.1.1.1 2007/09/02 11:06:17 mringe Exp $
   Comment:     Convert vector to matrix.
   --------------------------------------------------------------------------
   (C) Copyright 1999 Michael Ringe, Lehrstuhl D fuer Mathematik,
   RWTH Aachen, Germany  <mringe@math.rwth-aachen.de>
   This program is free software; see the file COPYING for details.
   ========================================================================== */


#include "meataxe.h"


/* --------------------------------------------------------------------------
   Local data
   -------------------------------------------------------------------------- */

MTX_DEFINE_FILE_INFO 



/**
!section algo.tp
!function VectorToMatrix "Convert vector to matrix"
 ** @param vecs
    List of vectors.
 ** @param n
    Number of the vector to convert.
 ** @param noc
    Desired number of columns.
 ** @return
    $0$ on success, $-1$ on error.
!description
    This function converts a vector with $m=rc$ entries into a $r\times c$ 
    matrix by filling the matrix from top to bottom and left to right with
    the entries of the vector. The vector is taken as the $n$-th row of
    |vecs|. A new matrix is allocated and returned. |noc| is the number of
    columns of the result, which must be a divisor of the number of columns 
    of |vecs|.
 ** @see MatrixToVector
 **/

Matrix_t *VectorToMatrix(Matrix_t *vecs, int n, int noc)

{
    int i;
    Matrix_t *result;

    /* Check arguments.
       ---------------- */
    if (!MatIsValid(vecs))
    {
	MTX_ERROR1("vecs: %E",MTX_ERR_BADARG);
	return NULL;
    }
    if (noc > vecs->Noc || vecs->Noc % noc != 0)
    {
	MTX_ERROR3("noc=%d (vec:%d): %E",noc,vecs->Noc,MTX_ERR_BADARG);
	return NULL;
    }

    /* Convert the vector.
       ------------------- */
    result = MatAlloc(vecs->Field,vecs->Noc / noc,noc);
    if (result == NULL)
	return NULL;
    for (i = 0; i < result->Nor; ++i)
    {
	if (MatCopyRegion(result,i,0, vecs,n,i*noc,1,noc) != 0)
	    MTX_ERROR("Copy failed");
    }
    return result;
}
